/*
 * Copyright (c) 2017, 2020 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests._byte.enumeration.enumeration_1;

import jakarta.xml.bind.*;
import javasoft.sqe.javatest.Status;
import java.io.PrintWriter;
import javasoft.sqe.tests.api.jakarta.xml.bind.CTTest;

public class enumeration1_GetSetCTTests extends CTTest {

    /**
     * Command line starter.
     */
    public static void main(String[] args) {
        enumeration1_GetSetCTTests test = new enumeration1_GetSetCTTests();
        PrintWriter err = new PrintWriter(System.err, true);
        PrintWriter out = new PrintWriter(System.out, true);
        Status status = test.run(args, err, out);
        err.flush();
        out.flush();
        status.exit();
    }

    public Status GetSet001( ) {
        String[] xmlDocNames = {
            "enumeration-1-1.xml", "enumeration-1-2.xml", "enumeration-1-3.xml",
            "enumeration-1-4.xml", "enumeration-1-5.xml"
        };
        byte[] expectedValues = {(byte)-33, (byte)86, (byte)-8, (byte)-8, (byte)7};
        byte[] anExpectedValues = {(byte)127, (byte)4, (byte)-19, (byte)-8, (byte)-128};
        
        for (int i = 0; i < xmlDocNames.length; ++i){
            JAXBElement<Byte> elemObj = (JAXBElement<Byte>)unmarshal(xmlDocNames[i]);
            if (elemObj.getValue() != expectedValues[i]){
                return Status.failed("used XML document: " + xmlDocNames[i] + ", elemObj.getValue() != " + expectedValues[i]);
            }
            elemObj.setValue(anExpectedValues[i]);
            if (elemObj.getValue() != anExpectedValues[i]){
                return Status.failed("used XML document: " + xmlDocNames[i] + ", elemObj.setValue(" + anExpectedValues[i] + 
                    ") invoked, " + "elemObj.getValue() != " + anExpectedValues[i]);
            }
        }
        return Status.passed("OKAY");
    }

    public Status GetSet002( ) {
        byte[] setValues = {(byte)-33, (byte)86, (byte)-8, (byte)-8, (byte)7};
        byte[] anSetValues = {(byte)127, (byte)4, (byte)-19, (byte)-8, (byte)-128};
        JAXBElement<Byte> elemObj = null;
        for (int i = 0; i < setValues.length; ++i){
            
                elemObj = (JAXBElement<Byte>)(new ObjectFactory()).createNISTSchemaByteEnumeration1(setValues[i]);
            
            if (elemObj.getValue() != setValues[i]){
                return Status.failed("dynamically created JAXBElement<Byte>, elemObj.getValue() != " + setValues[i]);
            }
            elemObj.setValue(anSetValues[i]);
            if (elemObj.getValue() != anSetValues[i]){
                return Status.failed("dynamically created JAXBElement<Byte>, elemObj.setValue(" + anSetValues[i] + 
                    ") invoked, " + "elemObj.getValue() != " + anSetValues[i]);
            }
        }
        return Status.passed("OKAY");
    }


}

